==> dde-network-core_1.0.64.orig.tar.xz: dde-network-core-1.0.64/dss-network-plugin/translations/dss-network-plugin_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.1">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 nuovo messaggio</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation>Connessione a %1</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 connesso</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation>%1 disconnesso</translation>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation>Impossibile connettersi a %1, controlla il tuo router o il cavo di rete.</translation>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation>Impossibile collegarsi a %1, avvicinati al router wireless</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation>Connessione fallita, impossibile connettersi a %1, password errata</translation>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation>Password richiesta per connettersi a %1</translation>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation>Il %1 802.11 WLAN non è stato trovato</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>Connessione cablata</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protocollo</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Tipo sicurezza</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Banda</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Canale</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interfaccia</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netmask</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS Primario</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefisso</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Velocità</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Dispositivo disattivato</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Connesso senza accesso ad internet</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Non connesso</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cavo di rete scollegato</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Connessione in corso</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Autentificazione in corso</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Ottenimento indirizzo IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Connesso</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Disconnesso</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Conflitto IP</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Connessione fallita</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Ottenimento indirizzo</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Connessione cablata</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Connessione cablata %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Connessione WiFi</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Rete wireless %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Dispositivo disattivato</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cavo di rete scollegato</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Non connesso</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Connessione in corso</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Connesso senza accesso ad internet</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Connessione fallita</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Conflitto IP</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Disattiva connessione cablata</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Attiva connessione cablata</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Disattiva connessione WiFi</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Attiva connessione WiFi</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Disabilita Rete</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Abilita Rete</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Impostazioni Rete</translation>
    </message>
</context>
</TS>

==> dde-network-core_1.1.5.orig.tar.xz: dde-network-core-1.1.5/dss-network-plugin/translations/dss-network-plugin_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="it">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 nuovo messaggio</translation>
    </message>
</context>
<context>
    <name>DeviceControllItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Connessione WiFi</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Connessione cablata</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation>Connessione a %1</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 connesso</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation>%1 disconnesso</translation>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation>Impossibile connettersi a %1, controlla il tuo router o il cavo di rete.</translation>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation>Impossibile collegarsi a %1, avvicinati al router wireless</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation>Connessione fallita, impossibile connettersi a %1, password errata</translation>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation>Password richiesta per connettersi a %1</translation>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation>Il %1 802.11 WLAN non è stato trovato</translation>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Connetti ad una rete nascosta</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>Connetti</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Nome (SSID)</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protocollo</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Tipo sicurezza</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Canale</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Banda</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interfaccia</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netmask</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS Primario</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefisso</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Velocità</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Dispositivo disattivato</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Connesso senza accesso ad internet</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Non connesso</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cavo di rete scollegato</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Connessione in corso</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Autentificazione in corso</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Ottenimento indirizzo IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Connesso</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Disconnesso</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Conflitto IP</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>Connessione fallita</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Ottenimento indirizzo</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Connessione cablata</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Connessione cablata %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Connessione WiFi</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Rete wireless %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Dispositivo disattivato</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cavo di rete scollegato</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Non connesso</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Connessione in corso</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Connesso senza accesso ad internet</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Connessione fallita</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Conflitto IP</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Disattiva connessione cablata</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Attiva connessione cablata</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Disattiva connessione WiFi</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Attiva connessione WiFi</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Disabilita Rete</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Abilita Rete</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Impostazioni Rete</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>Connessione cablata</translation>
    </message>
</context>
</TS>
